@@ -1,14 +1,11 @@
 # encoding: utf-8
 
-from sdsstools import get_logger, get_package_version
+from sdsstools import get_package_version
 
 
 NAME = 'sdss-flicamera'
 
 __version__ = get_package_version(__file__, 'sdss-flicamera') or 'dev'
 
-# Get a logger, mostly for warning formatting.
-log = get_logger(NAME)
-
 
 from .camera import *
