@@ -11,7 +11,6 @@
 import ctypes
 import os
 import pathlib
-import warnings
 from ctypes import (POINTER, byref, c_char_p, c_double, c_int,
                     c_long, c_size_t, c_ulong, c_void_p)
 
@@ -334,25 +333,19 @@ class LibFLI(ctypes.CDLL):
 
         self.domain = flidomain_t(FLIDOMAIN_USB | FLIDEVICE_CAMERA)
 
-        if not shared_object:
+        # For tests, we check if PYTEST_RUNNING is set, and in that case
+        # we skip this part. We'll mock LoadLibrary.
+        is_pytest = os.environ.get('PYTEST_RUNNING', '0')
+        if not shared_object and is_pytest != '1':  # pragma: no cover
             shared_object = list(pathlib.Path(__file__).parent.glob('libfli*.so'))
             if len(shared_object) == 0:
-                warnings.warn('the library was compiled without a copy of libfli. '
-                              'Trying to get it from the standard locations.', FLIWarning)
-            shared_object.append('libfli.so')  # In case the library exists in a system location.
-        else:
-            if not isinstance(shared_object, (list, tuple)):
-                shared_object = [shared_object]
+                raise OSError('The library was compiled without a copy of libfli.')
+            shared_object = shared_object[0]
 
-        for so in shared_object:
-            try:
-                self.libc = ctypes.cdll.LoadLibrary(so)
-                break
-            except OSError:
-                pass
+        self.libc = ctypes.cdll.LoadLibrary(shared_object)
 
         if self.libc is None:
-            raise RuntimeError('cannot load the libfli shared library.')
+            raise RuntimeError('Cannot load the libfli shared library.')
 
         # Sets the argtypes and restype.
         for funcname, argtypes in _API_FUNCTION_PROTOTYPES:
